# CONTRIBUTORS

This document lists those who have made contributions to the Project.
As per the contributor guidelines, they should be included by default in any publications derived from the Project.

If you are new to the project, don't forget to add your name and affiliation to the list of contributors here! Our Welcome Bot will send an automated message reminding this to first-time contributors.
Before every release, unlisted contributors will be invited again to add their names to this file (just in case they missed the automated message from our Welcome Bot).

| **Lastname** | **Name** | **Handle** | **ORCID** | **Affiliation** |
| --- | --- | --- | --- | --- |
| Adebimpe | Azeez | @a3sha2 | 0000-0001-9049-0135 | Perelman School of Medicine, University of Pennsylvania, PA, USA |
| Blair | Ross W. | @rwblair | 0000-0003-3007-1056 | Department of Psychology, Stanford University, CA, USA |
| Cieslak | Matthew | @mattcieslak | 0000-0002-1931-4734 | Perelman School of Medicine, University of Pennsylvania, PA, USA |
| MacNicol | Eilidh | @eilidhmacnicol | 0000-0003-3715-7012 | Department of Neuroimaging, King's College London |
| Naveau | Mikaël | @naveau | 0000-0001-6948-9068 | Cyceron, UMS 3408 (CNRS - UCBN), France |
| Pinsard | Basile | @bpinsard | 0000-0002-4391-3075 | University of Montréal, Montréal, Canada |
| Sitek | Kevin R. | @sitek | 0000-0002-2172-5786 | Speech & Hearing Bioscience & Technology Program, Harvard University |
| Sneve | Markus H. | @markushs | 0000-0001-7644-7915 | Center for Lifespan Changes in Brain and Cognition, University of Oslo |
